"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthBasic = void 0;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const auth_type_1 = require("./auth-type");
class AuthBasic {
    constructor(fnVerify) {
        this.fnVerify = fnVerify;
    }
    static init(fnVerify) {
        this.self = new AuthBasic(fnVerify);
    }
    static async createAccessToken(token, localeCode, username, password) {
        const payload = await this.instance.fnVerify({ username, password });
        const accessToken = {
            type: auth_type_1.AccessTokenType.Basic,
            grant: true,
            info: {
                token,
                auth: payload,
                requestedBy: payload?.userId || payload?.email || payload?.phone_number,
                localeCode: payload?.localeCode || localeCode || 'en_US'
            }
        };
        return accessToken;
    }
    static get instance() {
        return this.self || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'AuthBasic initialization is required');
    }
}
exports.AuthBasic = AuthBasic;
//# sourceMappingURL=auth-basic.js.map