"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasAbility = exports.isAuthenticated = exports.auth = void 0;
const ability_1 = require("@casl/ability");
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const http_1 = require("../http");
const auth_type_1 = require("./auth-type");
const auth_bearer_1 = require("./auth-bearer");
const auth_basic_1 = require("./auth-basic");
async function auth(req, authDirective) {
    const accessToken = (0, http_1.getAccessToken)(req);
    if (accessToken?.info?.token) {
        if (undefined === accessToken.grant) {
            switch (authDirective.type) {
                case auth_type_1.AccessTokenType.Bearer: {
                    const channel = req.get('x-channel');
                    const localeCode = req.get('language');
                    const _accessToken = await auth_bearer_1.AuthBearer.createAccessToken(accessToken?.info?.token, channel, localeCode);
                    // Set the access token into req object
                    (0, http_1.setAccessToken)(req, _accessToken);
                    return _accessToken;
                }
                case auth_type_1.AccessTokenType.Basic: {
                    const localeCode = req.get('language');
                    const loginInfo = accessToken.info.authMetadata;
                    const _accessToken = await auth_basic_1.AuthBasic.createAccessToken(accessToken?.info?.token, localeCode, loginInfo?.username, loginInfo?.password);
                    // Set the access token into req object
                    (0, http_1.setAccessToken)(req, _accessToken);
                    return _accessToken;
                }
            }
        }
        if (true === accessToken.grant) {
            return accessToken;
        }
    }
    (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.UNAUTHORISED, 'Unauthorized access', { hasToken: undefined !== accessToken?.info?.token, spec: authDirective });
}
exports.auth = auth;
function isAuthenticated(accessToken) {
    return true === accessToken?.grant;
}
exports.isAuthenticated = isAuthenticated;
function hasAbility(accessToken, spec) {
    if (!isAuthenticated(accessToken) || !spec) {
        (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.UNAUTHORISED, 'Unauthorized access', { accessToken, spec });
    }
    const { action, subject } = spec;
    const ability = (0, ability_1.defineAbility)((_can, cannot) => {
        cannot('manage', 'all');
    });
    const rules = accessToken.info?.auth?.rules;
    if (rules) {
        // Inspect ability by rules
        ability.update(JSON.parse(rules));
    }
    if (!ability.can(action, subject)) {
        ability_1.ForbiddenError.from(ability).throwUnlessCan(action, subject);
    }
}
exports.hasAbility = hasAbility;
//# sourceMappingURL=auth.js.map