"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseHandler = exports.Joi = void 0;
const joi_1 = __importDefault(require("joi"));
exports.Joi = joi_1.default;
const fs_1 = __importDefault(require("fs"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const error_1 = require("../error");
async function baseHandler(thisObject, fn, schema, request, info) {
    try {
        const { error, value } = schema.validate(request, { stripUnknown: true });
        if (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_PARAMETER, error.message, {
                function: fn.name,
                details: error.details,
                text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
            });
        }
        return fn.apply(thisObject, [value, info]);
    }
    catch (error) {
        if (request['path']) {
            fs_1.default.rmSync(request['path']);
        }
        if (!error_1.ErrorHandler.isEnabled) {
            (0, cm_libs_context_aware_error_1.throwFromError)(error);
        }
        const { code, message, statusCode } = await error_1.ErrorHandler.translate(error, error.statusCode, info?.localeCode);
        const params = {
            ...error.params,
            statusCode
        };
        (0, cm_libs_context_aware_error_1.throwError)(code, message, params);
    }
}
exports.baseHandler = baseHandler;
//# sourceMappingURL=validator.js.map