"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasAbilityDirective = exports.hasAbilityDirectiveTypeDefs = void 0;
const lodash_1 = __importDefault(require("lodash"));
const apollo_server_core_1 = require("apollo-server-core");
const utils_1 = require("@graphql-tools/utils");
const graphql_1 = require("graphql");
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const common_1 = require("../common");
exports.hasAbilityDirectiveTypeDefs = (0, apollo_server_core_1.gql) `
    directive @hasAbility(action: String, subject: String) on FIELD | FIELD_DEFINITION
`;
function hasAbilityDirective(schema, directiveName = 'hasAbility') {
    return (0, utils_1.mapSchema)(schema, {
        [utils_1.MapperKind.OBJECT_FIELD]: (fieldConfig) => {
            const hasAbilityDirective = (0, utils_1.getDirective)(schema, fieldConfig, directiveName)?.[0];
            if (hasAbilityDirective) {
                const { resolve = graphql_1.defaultFieldResolver } = fieldConfig;
                const keys = Object.keys(hasAbilityDirective);
                if (!(2 === keys.length && 'action' === keys[0] && 'subject' === keys[1])) {
                    (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_PARAMETER, 'Invalid directive: hasAbility(action, subject), missing argument');
                }
                const spec = {
                    action: hasAbilityDirective[keys[0]],
                    subject: hasAbilityDirective[keys[1]]
                };
                if (!lodash_1.default.isString(spec.action)) {
                    (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_PARAMETER, 'Invalid directive: hasAbility(action, subject), action must be a String');
                }
                if (!lodash_1.default.isString(spec.subject)) {
                    (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_PARAMETER, 'Invalid directive: hasAbility(action, subject), subject must be a String ');
                }
                fieldConfig.resolve = async (source, args, context, info) => {
                    const accessToken = (0, common_1.getAccessToken)(context?.req);
                    (0, common_1.hasAbility)(accessToken, spec);
                    return resolve(source, args, context, info);
                };
            }
            return fieldConfig;
        }
    });
}
exports.hasAbilityDirective = hasAbilityDirective;
//# sourceMappingURL=has-ability.directive.js.map