/// <reference types="node" />
/// <reference types="node" />
import net, { Socket } from 'net';
import { AppBase } from './app-base';
export * from 'net';
export { net };
export interface TcpConnection<T> {
    clientId: string;
    socket: Socket;
    buffer: Buffer;
    isIdle: boolean;
    ref?: T;
}
export declare abstract class TcpBase<T> extends AppBase {
    protected connections: Record<string, TcpConnection<T>>;
    private _connectionCount;
    protected abstract onConnected(connection: TcpConnection<T>): Promise<void>;
    protected abstract onClose(connection: TcpConnection<T>, error: Error | undefined): Promise<void>;
    protected abstract onData(connection: TcpConnection<T>, data: Buffer): Promise<number>;
    init(): Promise<this>;
    term(): Promise<void>;
    protected addConnection(socket: Socket, clientId: string, ref?: T, keepAliveInterval?: number, idleTimeout?: number): Promise<TcpConnection<T>>;
    protected removeConnection(clientId: string): boolean;
    private onDataEvent;
    private onCloseEvent;
    protected socketWrite(socket: Socket, data: Buffer): Promise<void>;
    protected get connectionCount(): number;
}
